@@ -1,10 +1,20 @@
 import requests
 
+
+class MyException(Exception):
+    pass
+
+
+
 def send(token,channel,content):
   url = 'https://discord.com/api/v9/channels/'+channel+'/messages'
   data = {"content": content}
   header = {"authorization": token}
   r = requests.post(url, data=data, headers=header)
+  try:
+    raise Exception(f"エラーが発生しました…")
+  except Exception as e:
+    print(e)
 
 def join(token,link,print="true"):
     if print == "false":
@@ -16,8 +26,10 @@ def join(token,link,print="true"):
      headers={'Authorization': token}
      requests.post(apilink, headers=headers)
      print(f"入れた～ {token}:{link}")
-     else:
-      print("error…tokenかlinkかprintが無効です…")
+    try:
+      raise Exception(f"エラーが発生しました…")
+    except Exception as e:
+      print(e)
       
 
 def leave(token,guild_id,print="true"):
@@ -30,8 +42,10 @@ def leave(token,guild_id,print="true"):
     apilink = "https://discord.com/api/v9/users/@me/guilds/" + guild_id
     requests.delete(url, headers=headers)
     print("抜けたよ～ {token}:{guild_id}")
-  else:
-    print("error tokenかguild_idが無効です")
+  try:
+    raise Exception(f"エラーが発生しました…")
+  except Exception as e:
+    print(e)
 
 def check(token,print="true"):
    if print == "false":
@@ -41,12 +55,22 @@ def check(token,print="true"):
      headers = {"authorization": token}
      userdata = requests.get("https://discord.com/api/9/users/@me", headers=headers).json()
      print(f"login {token} 使えるよ！ {userdata['username']}#{userdata['discriminator']}")
-   else:
-    print("使えないTOKEN {token}")
+   try:
+     raise Exception(f"エラーが発生しました…")
+   except Exception as e:
+     print(e)
 
 def report(token,guild_id,channel_id,message_id,reason):
   report = requests.post('https://discord.com/api/v9/report', json={'channel_id': channel_id,'message_id': message_id,'guild_id': guild_id,'reason': reason},headers={'authorization': token})
   if report.status_code == 200:
     print("通報成功")
+  try:
+    raise Exception(f"エラーが発生しました…")
+  except Exception as e:
+    print(e)
 def ditoloprint(message):
-  print(message)
\ No newline at end of file
+  print(message)
+  try:
+    raise Exception(f"エラーが発生しました…")
+  except Exception as e:
+    print(e)
\ No newline at end of file
